@@ -436,7 +436,7 @@ public class TestDorisTableOperations extends TestDoris {
     columns.add(
         JdbcColumn.builder()
             .withName("col_14")
-            .withType(Types.TimestampType.withoutTimeZone())
+            .withType(Types.TimestampType.withoutTimeZone(0))
             .build());
 
     Distribution distribution =
@@ -688,4 +688,55 @@ public class TestDorisTableOperations extends TestDoris {
     sql = DorisTableOperations.deleteIndexDefinition(load, deleteIndex3);
     Assertions.assertEquals("DROP INDEX uk_2", sql);
   }
+
+  @Test
+  public void testCalculateDatetimePrecision() {
+    Assertions.assertNull(
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATE", 10, 0),
+        "DATE type should return 0 precision");
+
+    Assertions.assertEquals(
+        0,
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATETIME", 20, 0),
+        "TIME type should return 0 precision");
+
+    Assertions.assertEquals(
+        3,
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATETIME", 23, 0),
+        "TIMESTAMP type should return 0 precision");
+
+    Assertions.assertEquals(
+        6,
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATETIME", 26, 0),
+        "TIMESTAMP type should return 0 precision");
+
+    Assertions.assertEquals(
+        9,
+        TABLE_OPERATIONS.calculateDatetimePrecision("DATETIME", 29, 0),
+        "Lower case type name should work");
+
+    Assertions.assertNull(
+        TABLE_OPERATIONS.calculateDatetimePrecision("VARCHAR", 50, 0),
+        "Non-datetime type should return 0 precision");
+  }
+
+  @Test
+  public void testCalculateDatetimePrecisionWithUnsupportedDriverVersion() {
+    DorisTableOperations operationsWithOldDriver =
+        new DorisTableOperations() {
+          @Override
+          protected String getMySQLDriverVersion() {
+            return "mysql-connector-java-8.0.11 (Revision: a0ca826f5cdf51a98356fdfb1bf251eb042f80bf)";
+          }
+
+          @Override
+          public boolean isMySQLDriverVersionSupported(String driverVersion) {
+            return false;
+          }
+        };
+
+    Assertions.assertNull(
+        operationsWithOldDriver.calculateDatetimePrecision("DATETIME", 26, 0),
+        "DATETIME type should return null for unsupported driver version");
+  }
 }
