@@ -18,6 +18,7 @@
  */
 package org.apache.gravitino.client;
 
+import static org.apache.gravitino.dto.util.DTOConverters.toDTO;
 import static org.apache.gravitino.dto.util.DTOConverters.toFunctionArg;
 
 import java.util.Collection;
@@ -35,19 +36,27 @@ import org.apache.gravitino.dto.CatalogDTO;
 import org.apache.gravitino.dto.MetalakeDTO;
 import org.apache.gravitino.dto.authorization.PrivilegeDTO;
 import org.apache.gravitino.dto.authorization.SecurableObjectDTO;
+import org.apache.gravitino.dto.job.JobTemplateDTO;
+import org.apache.gravitino.dto.job.ShellJobTemplateDTO;
+import org.apache.gravitino.dto.job.SparkJobTemplateDTO;
 import org.apache.gravitino.dto.requests.CatalogUpdateRequest;
 import org.apache.gravitino.dto.requests.FilesetUpdateRequest;
 import org.apache.gravitino.dto.requests.MetalakeUpdateRequest;
 import org.apache.gravitino.dto.requests.ModelUpdateRequest;
 import org.apache.gravitino.dto.requests.ModelVersionUpdateRequest;
+import org.apache.gravitino.dto.requests.PolicyUpdateRequest;
 import org.apache.gravitino.dto.requests.SchemaUpdateRequest;
 import org.apache.gravitino.dto.requests.TableUpdateRequest;
 import org.apache.gravitino.dto.requests.TagUpdateRequest;
 import org.apache.gravitino.dto.requests.TopicUpdateRequest;
 import org.apache.gravitino.file.FilesetChange;
+import org.apache.gravitino.job.JobTemplate;
+import org.apache.gravitino.job.ShellJobTemplate;
+import org.apache.gravitino.job.SparkJobTemplate;
 import org.apache.gravitino.messaging.TopicChange;
 import org.apache.gravitino.model.ModelChange;
 import org.apache.gravitino.model.ModelVersionChange;
+import org.apache.gravitino.policy.PolicyChange;
 import org.apache.gravitino.rel.Column;
 import org.apache.gravitino.rel.TableChange;
 import org.apache.gravitino.rel.expressions.Expression;
@@ -360,6 +369,27 @@ class DTOConverters {
     }
   }
 
+  static PolicyUpdateRequest toPolicyUpdateRequest(PolicyChange change) {
+    if (change instanceof PolicyChange.RenamePolicy) {
+      return new PolicyUpdateRequest.RenamePolicyRequest(
+          ((PolicyChange.RenamePolicy) change).getNewName());
+
+    } else if (change instanceof PolicyChange.UpdatePolicyComment) {
+      return new PolicyUpdateRequest.UpdatePolicyCommentRequest(
+          ((PolicyChange.UpdatePolicyComment) change).getNewComment());
+
+    } else if (change instanceof PolicyChange.UpdateContent) {
+      PolicyChange.UpdateContent updateContent = (PolicyChange.UpdateContent) change;
+      String policyType = updateContent.getPolicyType();
+      return new PolicyUpdateRequest.UpdatePolicyContentRequest(
+          policyType, toDTO(updateContent.getContent()));
+
+    } else {
+      throw new IllegalArgumentException(
+          "Unknown change type: " + change.getClass().getSimpleName());
+    }
+  }
+
   static ModelUpdateRequest toModelUpdateRequest(ModelChange change) {
     if (change instanceof ModelChange.RenameModel) {
       return new ModelUpdateRequest.RenameModelRequest(
@@ -405,8 +435,18 @@ class DTOConverters {
           ((ModelVersionChange.RemoveProperty) change).property());
 
     } else if (change instanceof ModelVersionChange.UpdateUri) {
+      ModelVersionChange.UpdateUri updateUri = (ModelVersionChange.UpdateUri) change;
       return new ModelVersionUpdateRequest.UpdateModelVersionUriRequest(
-          ((ModelVersionChange.UpdateUri) change).newUri());
+          updateUri.uriName(), updateUri.newUri());
+
+    } else if (change instanceof ModelVersionChange.AddUri) {
+      ModelVersionChange.AddUri addUri = (ModelVersionChange.AddUri) change;
+      return new ModelVersionUpdateRequest.AddModelVersionUriRequest(
+          addUri.uriName(), addUri.uri());
+
+    } else if (change instanceof ModelVersionChange.RemoveUri) {
+      return new ModelVersionUpdateRequest.RemoveModelVersionUriRequest(
+          ((ModelVersionChange.RemoveUri) change).uriName());
 
     } else if (change instanceof ModelVersionChange.UpdateAliases) {
       ModelVersionChange.UpdateAliases updateAliases = (ModelVersionChange.UpdateAliases) change;
@@ -419,4 +459,39 @@ class DTOConverters {
           "Unknown model version change type: " + change.getClass().getSimpleName());
     }
   }
+
+  static JobTemplateDTO toJobTemplateDTO(JobTemplate jobTemplate) {
+    switch (jobTemplate.jobType()) {
+      case SHELL:
+        return ShellJobTemplateDTO.builder()
+            .withJobType(jobTemplate.jobType())
+            .withName(jobTemplate.name())
+            .withComment(jobTemplate.comment())
+            .withExecutable(jobTemplate.executable())
+            .withArguments(jobTemplate.arguments())
+            .withEnvironments(jobTemplate.environments())
+            .withCustomFields(jobTemplate.customFields())
+            .withScripts(((ShellJobTemplate) jobTemplate).scripts())
+            .build();
+
+      case SPARK:
+        return SparkJobTemplateDTO.builder()
+            .withJobType(jobTemplate.jobType())
+            .withName(jobTemplate.name())
+            .withComment(jobTemplate.comment())
+            .withExecutable(jobTemplate.executable())
+            .withArguments(jobTemplate.arguments())
+            .withEnvironments(jobTemplate.environments())
+            .withCustomFields(jobTemplate.customFields())
+            .withClassName(((SparkJobTemplate) jobTemplate).className())
+            .withJars(((SparkJobTemplate) jobTemplate).jars())
+            .withFiles(((SparkJobTemplate) jobTemplate).files())
+            .withArchives(((SparkJobTemplate) jobTemplate).archives())
+            .withConfigs(((SparkJobTemplate) jobTemplate).configs())
+            .build();
+
+      default:
+        throw new IllegalArgumentException("Unsupported job type: " + jobTemplate.jobType());
+    }
+  }
 }
