@@ -100,18 +100,26 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
 
     @classmethod
     def setUpClass(cls):
-
         cls._get_gravitino_home()
 
         cls.hdfs_container = HDFSContainer()
         hdfs_container_ip = cls.hdfs_container.get_ip()
+        # copy hadoop tar from hdfs container
+        build_path = os.environ.get("PYTHON_BUILD_PATH")
+        dest_dir = os.path.join(build_path, "tmp")
+        os.makedirs(dest_dir, exist_ok=True)
+        cls.hdfs_container.get_tar_from_docker(
+            f"/opt/{BaseHadoopEnvironment.BASE_DIR_NAME}", dest_dir
+        )
         # init hadoop env
         BaseHadoopEnvironment.init_hadoop_env()
         cls.config = {
             "gravitino.bypass.fs.defaultFS": f"hdfs://{hdfs_container_ip}:9000"
         }
 
-        cls.hadoop_conf_path = f"{cls.gravitino_home}/catalogs/hadoop/conf/hadoop.conf"
+        cls.hadoop_conf_path = (
+            f"{cls.gravitino_home}/catalogs/fileset/conf/fileset.conf"
+        )
 
         # append the hadoop conf to server
         cls._append_conf(cls.config, cls.hadoop_conf_path)
@@ -218,8 +226,8 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
                 cls.fileset_ident,
                 catalog.as_fileset_catalog().drop_fileset(ident=cls.fileset_ident),
             )
-        except GravitinoRuntimeException:
-            logger.warning("Failed to drop fileset %s", cls.fileset_ident)
+        except GravitinoRuntimeException as e:
+            logger.warning("Failed to drop fileset %s: %s", cls.fileset_ident, str(e))
 
         try:
             logger.info(
@@ -229,8 +237,8 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
                     schema_name=cls.schema_name, cascade=True
                 ),
             )
-        except GravitinoRuntimeException:
-            logger.warning("Failed to drop schema %s", cls.schema_name)
+        except GravitinoRuntimeException as e:
+            logger.warning("Failed to drop schema %s: %s", cls.schema_name, str(e))
 
         try:
             logger.info(
@@ -238,17 +246,17 @@ class TestGvfsWithHDFS(IntegrationTestEnv):
                 cls.catalog_name,
                 cls.gravitino_client.drop_catalog(name=cls.catalog_name, force=True),
             )
-        except GravitinoRuntimeException:
-            logger.warning("Failed to drop catalog %s", cls.catalog_name)
+        except GravitinoRuntimeException as e:
+            logger.warning("Failed to drop catalog %s: %s", cls.catalog_name, str(e))
 
         try:
             logger.info(
                 "Drop metalake %s[%s]",
                 cls.metalake_name,
-                cls.gravitino_admin_client.drop_metalake(cls.metalake_name),
+                cls.gravitino_admin_client.drop_metalake(cls.metalake_name, force=True),
             )
-        except GravitinoRuntimeException:
-            logger.warning("Failed to drop metalake %s", cls.metalake_name)
+        except GravitinoRuntimeException as e:
+            logger.warning("Failed to drop metalake %s: %s", cls.metalake_name, str(e))
 
     def test_simple_auth(self):
         options = {"auth_type": "simple"}
