@@ -23,6 +23,7 @@ import org.apache.gravitino.audit.AuditLogManager;
 import org.apache.gravitino.authorization.AccessControlDispatcher;
 import org.apache.gravitino.authorization.AccessControlManager;
 import org.apache.gravitino.authorization.FutureGrantManager;
+import org.apache.gravitino.authorization.GravitinoAuthorizer;
 import org.apache.gravitino.authorization.OwnerDispatcher;
 import org.apache.gravitino.authorization.OwnerEventManager;
 import org.apache.gravitino.authorization.OwnerManager;
@@ -57,6 +58,8 @@ import org.apache.gravitino.hook.ModelHookDispatcher;
 import org.apache.gravitino.hook.SchemaHookDispatcher;
 import org.apache.gravitino.hook.TableHookDispatcher;
 import org.apache.gravitino.hook.TopicHookDispatcher;
+import org.apache.gravitino.job.JobManager;
+import org.apache.gravitino.job.JobOperationDispatcher;
 import org.apache.gravitino.listener.CatalogEventDispatcher;
 import org.apache.gravitino.listener.EventBus;
 import org.apache.gravitino.listener.EventListenerManager;
@@ -75,6 +78,9 @@ import org.apache.gravitino.metalake.MetalakeManager;
 import org.apache.gravitino.metalake.MetalakeNormalizeDispatcher;
 import org.apache.gravitino.metrics.MetricsSystem;
 import org.apache.gravitino.metrics.source.JVMMetricsSource;
+import org.apache.gravitino.policy.PolicyDispatcher;
+import org.apache.gravitino.policy.PolicyManager;
+import org.apache.gravitino.stats.StatisticManager;
 import org.apache.gravitino.storage.IdGenerator;
 import org.apache.gravitino.storage.RandomIdGenerator;
 import org.apache.gravitino.tag.TagDispatcher;
@@ -119,6 +125,8 @@ public class GravitinoEnv {
 
   private TagDispatcher tagDispatcher;
 
+  private PolicyDispatcher policyDispatcher;
+
   private AccessControlDispatcher accessControlDispatcher;
 
   private IdGenerator idGenerator;
@@ -133,9 +141,13 @@ public class GravitinoEnv {
 
   private AuditLogManager auditLogManager;
 
+  private JobOperationDispatcher jobOperationDispatcher;
+
   private EventBus eventBus;
   private OwnerDispatcher ownerDispatcher;
   private FutureGrantManager futureGrantManager;
+  private GravitinoAuthorizer gravitinoAuthorizer;
+  private StatisticManager statisticManager;
 
   protected GravitinoEnv() {}
 
@@ -339,6 +351,15 @@ public class GravitinoEnv {
     return tagDispatcher;
   }
 
+  /**
+   * Get the PolicyDispatcher associated with the Gravitino environment.
+   *
+   * @return The PolicyDispatcher instance.
+   */
+  public PolicyDispatcher policyDispatcher() {
+    return policyDispatcher;
+  }
+
   /**
    * Get the Owner dispatcher associated with the Gravitino environment.
    *
@@ -366,6 +387,38 @@ public class GravitinoEnv {
     return eventListenerManager;
   }
 
+  /**
+   * Set GravitinoAuthorizer to GravitinoEnv
+   *
+   * @param gravitinoAuthorizer the GravitinoAuthorizer instance
+   */
+  public void setGravitinoAuthorizer(GravitinoAuthorizer gravitinoAuthorizer) {
+    this.gravitinoAuthorizer = gravitinoAuthorizer;
+  }
+
+  /**
+   * Get The GravitinoAuthorizer
+   *
+   * @return the GravitinoAuthorizer instance
+   */
+  public GravitinoAuthorizer gravitinoAuthorizer() {
+    return gravitinoAuthorizer;
+  }
+
+  /**
+   * Get the JobOperationDispatcher associated with the Gravitino environment.
+   *
+   * @return The JobOperationDispatcher instance.
+   */
+  public JobOperationDispatcher jobOperationDispatcher() {
+    Preconditions.checkArgument(jobOperationDispatcher != null, "GravitinoEnv is not initialized.");
+    return jobOperationDispatcher;
+  }
+
+  public StatisticManager statisticManager() {
+    return statisticManager;
+  }
+
   public void start() {
     metricsSystem.start();
     eventListenerManager.start();
@@ -410,6 +463,23 @@ public class GravitinoEnv {
       metalakeManager.close();
     }
 
+    if (jobOperationDispatcher != null) {
+      try {
+        jobOperationDispatcher.close();
+        jobOperationDispatcher = null;
+      } catch (Exception e) {
+        LOG.warn("Failed to close JobOperationDispatcher", e);
+      }
+    }
+
+    if (statisticManager != null) {
+      try {
+        statisticManager.close();
+      } catch (Exception e) {
+        LOG.warn("Failed to close StatisticManager", e);
+      }
+    }
+
     LOG.info("Gravitino Environment is shut down.");
   }
 
@@ -501,6 +571,7 @@ public class GravitinoEnv {
     ModelNormalizeDispatcher modelNormalizeDispatcher =
         new ModelNormalizeDispatcher(modelHookDispatcher, catalogManager);
     this.modelDispatcher = new ModelEventDispatcher(eventBus, modelNormalizeDispatcher);
+    this.statisticManager = new StatisticManager(entityStore, idGenerator, config);
 
     // Create and initialize access control related modules
     boolean enableAuthorization = config.get(Configs.ENABLE_AUTHORIZATION);
@@ -525,5 +596,10 @@ public class GravitinoEnv {
 
     // Create and initialize Tag related modules
     this.tagDispatcher = new TagEventDispatcher(eventBus, new TagManager(idGenerator, entityStore));
+    // todo: support policy event dispatcher
+    this.policyDispatcher = new PolicyManager(idGenerator, entityStore);
+
+    // TODO: Support event for job operation dispatcher
+    this.jobOperationDispatcher = new JobManager(config, entityStore, idGenerator);
   }
 }
