@@ -48,6 +48,7 @@ import org.apache.gravitino.meta.FilesetEntity;
 import org.apache.gravitino.meta.GroupEntity;
 import org.apache.gravitino.meta.ModelEntity;
 import org.apache.gravitino.meta.ModelVersionEntity;
+import org.apache.gravitino.meta.PolicyEntity;
 import org.apache.gravitino.meta.RoleEntity;
 import org.apache.gravitino.meta.SchemaEntity;
 import org.apache.gravitino.meta.SchemaVersion;
@@ -55,6 +56,8 @@ import org.apache.gravitino.meta.TableEntity;
 import org.apache.gravitino.meta.TagEntity;
 import org.apache.gravitino.meta.TopicEntity;
 import org.apache.gravitino.meta.UserEntity;
+import org.apache.gravitino.policy.Policy;
+import org.apache.gravitino.policy.PolicyContent;
 import org.apache.gravitino.rel.Column;
 import org.apache.gravitino.rel.expressions.Expression;
 import org.apache.gravitino.rel.types.Type;
@@ -71,6 +74,9 @@ import org.apache.gravitino.storage.relational.po.ModelPO;
 import org.apache.gravitino.storage.relational.po.ModelVersionAliasRelPO;
 import org.apache.gravitino.storage.relational.po.ModelVersionPO;
 import org.apache.gravitino.storage.relational.po.OwnerRelPO;
+import org.apache.gravitino.storage.relational.po.PolicyMetadataObjectRelPO;
+import org.apache.gravitino.storage.relational.po.PolicyPO;
+import org.apache.gravitino.storage.relational.po.PolicyVersionPO;
 import org.apache.gravitino.storage.relational.po.RolePO;
 import org.apache.gravitino.storage.relational.po.SchemaPO;
 import org.apache.gravitino.storage.relational.po.SecurableObjectPO;
@@ -84,8 +90,8 @@ import org.apache.gravitino.utils.PrincipalUtils;
 
 /** POConverters is a utility class to convert PO to Base and vice versa. */
 public class POConverters {
-  private static final long INIT_VERSION = 1L;
-  private static final long DEFAULT_DELETED_AT = 0L;
+  public static final long INIT_VERSION = 1L;
+  public static final long DEFAULT_DELETED_AT = 0L;
 
   private POConverters() {}
 
@@ -182,8 +188,10 @@ public class POConverters {
   /**
    * Initialize CatalogPO
    *
-   * @param catalogEntity CatalogEntity object
-   * @return CatalogPO object with version initialized
+   * @param catalogEntity the {@link CatalogEntity} containing source metadata for the catalog
+   * @param metalakeId the identifier of the metalake environment to which this catalog belongs
+   * @return {@link CatalogPO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static CatalogPO initializeCatalogPOWithVersion(
       CatalogEntity catalogEntity, Long metalakeId) {
@@ -210,9 +218,11 @@ public class POConverters {
   /**
    * Update CatalogPO version
    *
-   * @param oldCatalogPO the old CatalogPO object
-   * @param newCatalog the new CatalogEntity object
-   * @return CatalogPO object with updated version
+   * @param oldCatalogPO the existing {@link CatalogPO} containing the version to preserve
+   * @param newCatalog the {@link CatalogEntity} with updated catalog metadata
+   * @param metalakeId the identifier of the metalake environment for this catalog
+   * @return {@code CatalogPO} object with updated version
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static CatalogPO updateCatalogPOWithVersion(
       CatalogPO oldCatalogPO, CatalogEntity newCatalog, Long metalakeId) {
@@ -281,8 +291,10 @@ public class POConverters {
   /**
    * Initialize SchemaPO
    *
-   * @param schemaEntity SchemaEntity object
-   * @return CatalogPO object with version initialized
+   * @param schemaEntity the {@link SchemaEntity} containing source data for the PO object
+   * @param builder the {@link SchemaPO.Builder} used to assemble the {@link SchemaPO}
+   * @return {@code CatalogPO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static SchemaPO initializeSchemaPOWithVersion(
       SchemaEntity schemaEntity, SchemaPO.Builder builder) {
@@ -370,8 +382,10 @@ public class POConverters {
   /**
    * Initialize TablePO
    *
-   * @param tableEntity TableEntity object
-   * @return TablePO object with version initialized
+   * @param tableEntity the {@link TableEntity} containing source data for the PO object
+   * @param builder the {@link TablePO.Builder} used to assemble the {@link TablePO}
+   * @return {@code TablePO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static TablePO initializeTablePOWithVersion(
       TableEntity tableEntity, TablePO.Builder builder) {
@@ -538,8 +552,10 @@ public class POConverters {
   /**
    * Initialize FilesetPO
    *
-   * @param filesetEntity FilesetEntity object
-   * @return FilesetPO object with version initialized
+   * @param filesetEntity the source {@link FilesetEntity} object
+   * @param builder the {@link FilesetPO.Builder} used to assemble the {@link FilesetPO}
+   * @return {@code FilesetPO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static FilesetPO initializeFilesetPOWithVersion(
       FilesetEntity filesetEntity, FilesetPO.Builder builder) {
@@ -580,9 +596,12 @@ public class POConverters {
   /**
    * Update FilesetPO version
    *
-   * @param oldFilesetPO the old FilesetPO object
-   * @param newFileset the new FilesetEntity object
-   * @return FilesetPO object with updated version
+   * @param oldFilesetPO the existing {@link FilesetPO} containing the current and last version data
+   * @param newFileset the {@link FilesetEntity} with updated metadata and storage locations
+   * @param needUpdateVersion true to increment and update version fields; false to keep versions
+   *     unchanged
+   * @return {@code FilesetPO} object with updated version
+   * @throws RuntimeException if JSON serialization of properties fails
    */
   public static FilesetPO updateFilesetPOWithVersion(
       FilesetPO oldFilesetPO, FilesetEntity newFileset, boolean needUpdateVersion) {
@@ -659,6 +678,66 @@ public class POConverters {
     }
   }
 
+  public static boolean checkPolicyVersionNeedUpdate(
+      PolicyVersionPO oldPolicyVersionPO, PolicyEntity newPolicy) {
+    if (!StringUtils.equals(oldPolicyVersionPO.getPolicyComment(), newPolicy.comment())
+        || oldPolicyVersionPO.isEnabled() != newPolicy.enabled()) {
+      return true;
+    }
+
+    try {
+      PolicyContent oldContent =
+          JsonUtils.anyFieldMapper()
+              .readValue(oldPolicyVersionPO.getContent(), newPolicy.policyType().contentClass());
+      if (oldContent == null) {
+        return newPolicy.content() != null;
+      }
+      return !oldContent.equals(newPolicy.content());
+    } catch (JsonProcessingException e) {
+      throw new RuntimeException("Failed to deserialize json object:", e);
+    }
+  }
+
+  public static PolicyPO updatePolicyPOWithVersion(
+      PolicyPO oldPolicyPO, PolicyEntity newPolicy, boolean needUpdateVersion) {
+    try {
+      Long lastVersion = oldPolicyPO.getLastVersion();
+      Long currentVersion;
+      PolicyVersionPO newPolicyVersionPO;
+      // Will set the version to the last version + 1
+      if (needUpdateVersion) {
+        lastVersion++;
+        currentVersion = lastVersion;
+        newPolicyVersionPO =
+            PolicyVersionPO.builder()
+                .withMetalakeId(oldPolicyPO.getMetalakeId())
+                .withPolicyId(newPolicy.id())
+                .withVersion(currentVersion)
+                .withPolicyComment(newPolicy.comment())
+                .withEnabled(newPolicy.enabled())
+                .withContent(JsonUtils.anyFieldMapper().writeValueAsString(newPolicy.content()))
+                .withDeletedAt(DEFAULT_DELETED_AT)
+                .build();
+      } else {
+        currentVersion = oldPolicyPO.getCurrentVersion();
+        newPolicyVersionPO = oldPolicyPO.getPolicyVersionPO();
+      }
+      return PolicyPO.builder()
+          .withPolicyId(newPolicy.id())
+          .withPolicyName(newPolicy.name())
+          .withPolicyType(newPolicy.policyType().name())
+          .withMetalakeId(oldPolicyPO.getMetalakeId())
+          .withAuditInfo(JsonUtils.anyFieldMapper().writeValueAsString(newPolicy.auditInfo()))
+          .withCurrentVersion(currentVersion)
+          .withLastVersion(lastVersion)
+          .withDeletedAt(DEFAULT_DELETED_AT)
+          .withPolicyVersionPO(newPolicyVersionPO)
+          .build();
+    } catch (JsonProcessingException e) {
+      throw new RuntimeException("Failed to serialize json object:", e);
+    }
+  }
+
   /**
    * Convert {@link FilesetPO} to {@link FilesetEntity}
    *
@@ -771,8 +850,10 @@ public class POConverters {
   /**
    * Initialize UserPO
    *
-   * @param userEntity UserEntity object
-   * @return UserPO object with version initialized
+   * @param userEntity the {@link UserEntity} containing source data for the PO object
+   * @param builder the {@link UserPO.Builder} used to assemble the {@link UserPO}
+   * @return {@code UserPO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static UserPO initializeUserPOWithVersion(UserEntity userEntity, UserPO.Builder builder) {
     try {
@@ -1017,8 +1098,10 @@ public class POConverters {
   /**
    * Initialize RolePO
    *
-   * @param roleEntity RoleEntity object
-   * @return RolePO object with version initialized
+   * @param roleEntity the {@link RoleEntity} containing source data for the PO object
+   * @param builder the {@link RolePO.Builder} used to assemble the {@link RolePO}
+   * @return {@code RolePO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static RolePO initializeRolePOWithVersion(RoleEntity roleEntity, RolePO.Builder builder) {
     try {
@@ -1039,8 +1122,10 @@ public class POConverters {
   /**
    * Initialize GroupPO
    *
-   * @param groupEntity GroupEntity object
-   * @return GroupPO object with version initialized
+   * @param groupEntity the {@link GroupEntity} containing source data for the PO object
+   * @param builder the {@link GroupPO.Builder} used to assemble the {@link GroupPO}
+   * @return {@code GroupPO} object with version initialized
+   * @throws RuntimeException if JSON serialization of the entity fails
    */
   public static GroupPO initializeGroupPOWithVersion(
       GroupEntity groupEntity, GroupPO.Builder builder) {
@@ -1286,6 +1371,79 @@ public class POConverters {
     }
   }
 
+  public static PolicyEntity fromPolicyPO(PolicyPO policyPO, Namespace namespace) {
+    try {
+      Policy.BuiltInType policyType = Policy.BuiltInType.fromPolicyType(policyPO.getPolicyType());
+      return PolicyEntity.builder()
+          .withId(policyPO.getPolicyId())
+          .withName(policyPO.getPolicyName())
+          .withNamespace(namespace)
+          .withPolicyType(policyType)
+          .withComment(policyPO.getPolicyVersionPO().getPolicyComment())
+          .withEnabled(policyPO.getPolicyVersionPO().isEnabled())
+          .withContent(
+              JsonUtils.anyFieldMapper()
+                  .readValue(policyPO.getPolicyVersionPO().getContent(), policyType.contentClass()))
+          .withAuditInfo(
+              JsonUtils.anyFieldMapper().readValue(policyPO.getAuditInfo(), AuditInfo.class))
+          .build();
+    } catch (JsonProcessingException e) {
+      throw new RuntimeException("Failed to deserialize json object:", e);
+    }
+  }
+
+  public static PolicyPO initializePolicyPOWithVersion(
+      PolicyEntity policyEntity, PolicyPO.Builder builder) {
+    try {
+      String content = JsonUtils.anyFieldMapper().writeValueAsString(policyEntity.content());
+      PolicyVersionPO policyVersionPO =
+          PolicyVersionPO.builder()
+              .withMetalakeId(builder.getMetalakeId())
+              .withPolicyId(policyEntity.id())
+              .withVersion(INIT_VERSION)
+              .withPolicyComment(policyEntity.comment())
+              .withEnabled(policyEntity.enabled())
+              .withContent(content)
+              .withDeletedAt(DEFAULT_DELETED_AT)
+              .build();
+      return builder
+          .withPolicyId(policyEntity.id())
+          .withPolicyName(policyEntity.name())
+          .withPolicyType(policyEntity.policyType().name())
+          .withAuditInfo(JsonUtils.anyFieldMapper().writeValueAsString(policyEntity.auditInfo()))
+          .withCurrentVersion(INIT_VERSION)
+          .withLastVersion(INIT_VERSION)
+          .withDeletedAt(DEFAULT_DELETED_AT)
+          .withPolicyVersionPO(policyVersionPO)
+          .build();
+    } catch (JsonProcessingException e) {
+      throw new RuntimeException("Failed to serialize json object:", e);
+    }
+  }
+
+  public static PolicyMetadataObjectRelPO initializePolicyMetadataObjectRelPOWithVersion(
+      Long policyId, Long metadataObjectId, String metadataObjectType) {
+    try {
+      AuditInfo auditInfo =
+          AuditInfo.builder()
+              .withCreator(PrincipalUtils.getCurrentPrincipal().getName())
+              .withCreateTime(Instant.now())
+              .build();
+
+      return PolicyMetadataObjectRelPO.builder()
+          .withPolicyId(policyId)
+          .withMetadataObjectId(metadataObjectId)
+          .withMetadataObjectType(metadataObjectType)
+          .withAuditInfo(JsonUtils.anyFieldMapper().writeValueAsString(auditInfo))
+          .withCurrentVersion(INIT_VERSION)
+          .withLastVersion(INIT_VERSION)
+          .withDeletedAt(DEFAULT_DELETED_AT)
+          .build();
+    } catch (JsonProcessingException e) {
+      throw new RuntimeException("Failed to serialize json object:", e);
+    }
+  }
+
   public static OwnerRelPO initializeOwnerRelPOsWithVersion(
       Long metalakeId,
       String ownerType,
@@ -1351,20 +1509,26 @@ public class POConverters {
 
   public static ModelVersionEntity fromModelVersionPO(
       NameIdentifier modelIdent,
-      ModelVersionPO modelVersionPO,
+      List<ModelVersionPO> modelVersionPOs,
       List<ModelVersionAliasRelPO> aliasRelPOs) {
     List<String> aliases =
         aliasRelPOs.stream()
             .map(ModelVersionAliasRelPO::getModelVersionAlias)
             .collect(Collectors.toList());
 
+    Map<String, String> uris =
+        modelVersionPOs.stream()
+            .collect(
+                Collectors.toMap(
+                    ModelVersionPO::getModelVersionUriName, ModelVersionPO::getModelVersionUri));
+    ModelVersionPO modelVersionPO = modelVersionPOs.get(0);
     try {
       return ModelVersionEntity.builder()
           .withModelIdentifier(modelIdent)
           .withVersion(modelVersionPO.getModelVersion())
           .withAliases(aliases)
           .withComment(modelVersionPO.getModelVersionComment())
-          .withUri(modelVersionPO.getModelVersionUri())
+          .withUris(uris)
           .withProperties(
               JsonUtils.anyFieldMapper()
                   .readValue(modelVersionPO.getModelVersionProperties(), Map.class))
@@ -1420,7 +1584,10 @@ public class POConverters {
           .withMetalakeId(oldModelVersionPO.getMetalakeId())
           .withCatalogId(oldModelVersionPO.getCatalogId())
           .withSchemaId(oldModelVersionPO.getSchemaId())
-          .withModelVersionUri(newModelVersion.uri())
+          // The modelVersionUriName and modelVersionUri here are not actually used.
+          // They are only used for occupying positions to avoid verification failures.
+          .withModelVersionUriName(oldModelVersionPO.getModelVersionUriName())
+          .withModelVersionUri(oldModelVersionPO.getModelVersionUri())
           .withModelVersion(oldModelVersionPO.getModelVersion())
           .withModelVersionComment(newModelVersion.comment())
           .withModelVersionProperties(
@@ -1455,21 +1622,30 @@ public class POConverters {
     }
   }
 
-  public static ModelVersionPO initializeModelVersionPO(
-      ModelVersionEntity modelVersionEntity, ModelVersionPO.Builder builder) {
+  public static List<ModelVersionPO> initializeModelVersionPO(
+      ModelVersionEntity modelVersionEntity, Long modelId) {
     try {
-      return builder
-          // Note that version set here will not be used when inserting into database, it will
-          // directly use the version from the query to avoid concurrent version conflict.
-          .withModelVersion(modelVersionEntity.version())
-          .withModelVersionComment(modelVersionEntity.comment())
-          .withModelVersionUri(modelVersionEntity.uri())
-          .withModelVersionProperties(
-              JsonUtils.anyFieldMapper().writeValueAsString(modelVersionEntity.properties()))
-          .withAuditInfo(
-              JsonUtils.anyFieldMapper().writeValueAsString(modelVersionEntity.auditInfo()))
-          .withDeletedAt(DEFAULT_DELETED_AT)
-          .build();
+      String modelVersionProperties =
+          JsonUtils.anyFieldMapper().writeValueAsString(modelVersionEntity.properties());
+      String modelVersionAuditInfo =
+          JsonUtils.anyFieldMapper().writeValueAsString(modelVersionEntity.auditInfo());
+      return modelVersionEntity.uris().entrySet().stream()
+          .map(
+              entry ->
+                  ModelVersionPO.builder()
+                      .withModelId(modelId)
+                      // Note that version set here will not be used when inserting into database,
+                      // it will directly use the version from the query to avoid concurrent version
+                      // conflict.
+                      .withModelVersion(modelVersionEntity.version())
+                      .withModelVersionComment(modelVersionEntity.comment())
+                      .withModelVersionUriName(entry.getKey())
+                      .withModelVersionUri(entry.getValue())
+                      .withModelVersionProperties(modelVersionProperties)
+                      .withAuditInfo(modelVersionAuditInfo)
+                      .withDeletedAt(DEFAULT_DELETED_AT)
+                      .build())
+          .collect(Collectors.toList());
     } catch (JsonProcessingException e) {
       throw new RuntimeException("Failed to serialize json object:", e);
     }
