@@ -30,6 +30,7 @@ import org.apache.gravitino.integration.test.web.ui.utils.BaseWebIT;
 import org.openqa.selenium.By;
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.Keys;
+import org.openqa.selenium.StaleElementReferenceException;
 import org.openqa.selenium.WebDriver;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.support.FindBy;
@@ -134,6 +135,12 @@ public class CatalogsPage extends BaseWebIT {
   @FindBy(xpath = "//div[@data-refer='tab-details-panel']")
   public WebElement tabDetailsContent;
 
+  @FindBy(xpath = "//button[@data-refer='tab-files']")
+  public WebElement tabFilesBtn;
+
+  @FindBy(xpath = "//div[@data-refer='tab-files-panel']")
+  public WebElement tabFilesContent;
+
   @FindBy(xpath = "//div[@data-refer='details-drawer']")
   public WebElement detailsDrawer;
 
@@ -318,14 +325,17 @@ public class CatalogsPage extends BaseWebIT {
     }
   }
 
-  public void setFilesetStorageLocationField(String storageLocation) {
+  public void setFilesetStorageLocationField(
+      int index, String locationName, String storageLocation) {
     try {
-      WebElement filesetStorageLocationFieldInput =
-          filesetStorageLocationField.findElement(By.tagName("input"));
-      filesetStorageLocationFieldInput.sendKeys(
-          Keys.chord(Keys.HOME, Keys.chord(Keys.SHIFT, Keys.END), Keys.DELETE));
-      filesetStorageLocationFieldInput.clear();
-      filesetStorageLocationFieldInput.sendKeys(storageLocation);
+      // Set the indexed storageLocations name
+      String namePath = "//div[@data-refer='storageLocations-name-" + index + "']//input";
+      WebElement nameInput = driver.findElement(By.xpath(namePath));
+      nameInput.sendKeys(locationName);
+      // Set the indexed storageLocations location
+      String locationPath = "//div[@data-refer='storageLocations-location-" + index + "']//input";
+      WebElement locationInput = driver.findElement(By.xpath(locationPath));
+      locationInput.sendKeys(storageLocation);
     } catch (Exception e) {
       LOG.error(e.getMessage(), e);
     }
@@ -571,6 +581,16 @@ public class CatalogsPage extends BaseWebIT {
     }
   }
 
+  public boolean verifyShowFilesContent() {
+    try {
+      String files = tabFilesContent.getAttribute("hidden");
+      return Objects.equals(files, null);
+    } catch (Exception e) {
+      LOG.error(e.getMessage(), e);
+      return false;
+    }
+  }
+
   public boolean verifyShowCatalogDetails(String name, String hiveMetastoreUris)
       throws InterruptedException {
     try {
@@ -718,19 +738,34 @@ public class CatalogsPage extends BaseWebIT {
     if (isColumnLevel) {
       xpath = xpath + "//p";
     }
-    List<WebElement> list =
-        wait.until(ExpectedConditions.visibilityOfAllElementsLocatedBy(By.xpath(xpath)));
-    List<String> texts = new ArrayList<>();
-    for (WebElement element : list) {
-      texts.add(element.getText());
-    }
 
-    if (!texts.contains(itemName)) {
-      LOG.error("table list: {} does not include itemName: {}", texts, itemName);
+    try {
+      List<WebElement> list =
+          wait.until(ExpectedConditions.visibilityOfAllElementsLocatedBy(By.xpath(xpath)));
+      List<String> texts = new ArrayList<>();
+
+      for (int i = 0; i < list.size(); i++) {
+        try {
+          texts.add(list.get(i).getText());
+        } catch (StaleElementReferenceException e) {
+          // Element failed, re-find and obtain text
+          List<WebElement> refreshedList = driver.findElements(By.xpath(xpath));
+          if (i < refreshedList.size()) {
+            texts.add(refreshedList.get(i).getText());
+          }
+        }
+      }
+
+      if (!texts.contains(itemName)) {
+        LOG.error("table list: {} does not include itemName: {}", texts, itemName);
+      }
+
+      return texts.contains(itemName);
+    } catch (StaleElementReferenceException e) {
+      // The entire lookup process failed, return false to let the outer layer retry.
+      LOG.warn("Elements became stale during verification, will retry", e);
       return false;
     }
-
-    return true;
   }
 
   public boolean verifyNoDataItemInList(String itemName, Boolean isColumnLevel) {
@@ -765,7 +800,8 @@ public class CatalogsPage extends BaseWebIT {
 
   public boolean verifyTableColumns() {
     try {
-      List<String> columns = Arrays.asList("Name", "Type", "Nullable", "AutoIncrement", "Comment");
+      List<String> columns =
+          Arrays.asList("Name", "Type", "Nullable", "AutoIncrement", "Default Value", "Comment");
 
       List<WebElement> columnHeadersRows =
           columnHeaders.findElements(By.xpath("./div[@role='columnheader']"));
