@@ -50,7 +50,7 @@ import { yupResolver } from '@hookform/resolvers/yup'
 
 import { groupBy } from 'lodash-es'
 import { genUpdates } from '@/lib/utils'
-import { providers, filesetProviders, messagingProviders } from '@/lib/utils/initial'
+import { providers, messagingProviders } from '@/lib/utils/initial'
 import { nameRegex, nameRegexDesc, keyRegex } from '@/lib/utils/regex'
 import { useSearchParams } from 'next/navigation'
 
@@ -69,8 +69,6 @@ const schema = yup.object().shape({
     switch (type) {
       case 'relational':
         return schema.oneOf(providers.map(i => i.value)).required()
-      case 'fileset':
-        return schema.oneOf(filesetProviders.map(i => i.value)).required()
       case 'messaging':
         return schema.oneOf(messagingProviders.map(i => i.value)).required()
       default:
@@ -123,6 +121,19 @@ const CreateCatalogDialog = props => {
 
   const providerSelect = watch('provider')
   const typeSelect = watch('type')
+  const catalogBackendSelect = watch('propItems').find(i => i.key === 'catalog-backend')?.value
+
+  useEffect(() => {
+    const updateProps = innerProps.map(item => {
+      if (item.key === 'warehouse') {
+        return { ...item, required: ['hive', 'jdbc'].includes(catalogBackendSelect) }
+      }
+
+      return item
+    })
+    setInnerProps(updateProps)
+    // eslint-disable-next-line react-hooks/exhaustive-deps
+  }, [catalogBackendSelect])
 
   const handleFormChange = ({ index, event }) => {
     let data = [...innerProps]
@@ -174,7 +185,7 @@ const CreateCatalogDialog = props => {
     const parentField = innerProps.find(i => i.key === field.parentField)
 
     const check =
-      (parentField && field.hide.includes(parentField.value)) ||
+      (parentField && field.hide?.includes(parentField.value)) ||
       (field.parentField === 'authentication.type' && parentField === undefined)
 
     return check
@@ -219,7 +230,7 @@ const CreateCatalogDialog = props => {
 
     if (
       propItems[0]?.key === 'catalog-backend' &&
-      propItems[0]?.value === 'hive' &&
+      ['hive', 'rest'].includes(propItems[0]?.value) &&
       ['lakehouse-iceberg', 'lakehouse-paimon'].includes(providerSelect)
     ) {
       nextProps = propItems.filter(item => !['jdbc-driver', 'jdbc-user', 'jdbc-password'].includes(item.key))
@@ -229,14 +240,6 @@ const CreateCatalogDialog = props => {
       providerSelect === 'lakehouse-paimon'
     ) {
       nextProps = propItems.filter(item => !['jdbc-driver', 'jdbc-user', 'jdbc-password', 'uri'].includes(item.key))
-    } else if (
-      propItems[0]?.key === 'catalog-backend' &&
-      propItems[0]?.value === 'rest' &&
-      providerSelect === 'lakehouse-iceberg'
-    ) {
-      nextProps = propItems.filter(
-        item => !['jdbc-driver', 'jdbc-user', 'jdbc-password', 'warehouse'].includes(item.key)
-      )
     }
     const parentField = nextProps.find(i => i.key === 'authentication.type')
     if (!parentField || parentField?.value === 'simple') {
@@ -267,6 +270,7 @@ const CreateCatalogDialog = props => {
           'jdbc-driver': jdbcDriver,
           'jdbc-user': jdbcUser,
           'jdbc-password': jdbcPwd,
+          warehouse: warehouse,
           uri: uri,
           'authentication.type': authType,
           'authentication.kerberos.principal': kerberosPrincipal,
@@ -276,7 +280,7 @@ const CreateCatalogDialog = props => {
 
         if (
           catalogBackend &&
-          catalogBackend === 'hive' &&
+          ['rest', 'hive'].includes(catalogBackend) &&
           ['lakehouse-iceberg', 'lakehouse-paimon'].includes(providerSelect)
         ) {
           properties = {
@@ -284,18 +288,13 @@ const CreateCatalogDialog = props => {
             uri: uri,
             ...others
           }
+          warehouse && (properties['warehouse'] = warehouse)
         } else if (catalogBackend && catalogBackend === 'filesystem' && providerSelect === 'lakehouse-paimon') {
           properties = {
             'catalog-backend': catalogBackend,
             ...others
           }
           uri && (properties['uri'] = uri)
-        } else if (catalogBackend && catalogBackend === 'rest' && providerSelect === 'lakehouse-iceberg') {
-          properties = {
-            'catalog-backend': catalogBackend,
-            uri: uri,
-            ...others
-          }
         } else {
           properties = {
             uri: uri,
@@ -349,16 +348,12 @@ const CreateCatalogDialog = props => {
         setValue('provider', 'hive')
         break
       }
-      case 'fileset': {
-        setProviderTypes(filesetProviders)
-        setValue('provider', 'hadoop')
-        break
-      }
       case 'messaging': {
         setProviderTypes(messagingProviders)
         setValue('provider', 'kafka')
         break
       }
+      case 'fileset':
       case 'model': {
         setProviderTypes([])
         setValue('provider', '')
@@ -404,14 +399,11 @@ const CreateCatalogDialog = props => {
           providersItems = providers
           break
         }
-        case 'fileset': {
-          providersItems = filesetProviders
-          break
-        }
         case 'messaging': {
           providersItems = messagingProviders
           break
         }
+        case 'fileset':
         case 'model': {
           providersItems = []
           break
@@ -444,7 +436,8 @@ const CreateCatalogDialog = props => {
         if (findPropIndex === -1) {
           let propItem = {
             key: item,
-            value: properties[item]
+            value: properties[item],
+            disabled: type === 'update' && item.startsWith('location-') && data.provider === 'fileset'
           }
           propsItems.push(propItem)
         }
@@ -532,7 +525,7 @@ const CreateCatalogDialog = props => {
               </FormControl>
             </Grid>
 
-            {typeSelect !== 'model' && (
+            {!['model', 'fileset'].includes(typeSelect) && (
               <Grid item xs={12}>
                 <FormControl fullWidth>
                   <InputLabel id='select-catalog-provider' error={Boolean(errors.provider)}>
